@@ -1,35 +1,35 @@
-/* This file is part of the KDE project
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
 
-   Copyright (C) 2011 Dominik Haumann <dhaumann kde org>
-   Copyright (C) 2013 Gerald Senarclens de Grancy <oss@senarclens.eu>
+    Copyright (C) 2011-2018 Dominik Haumann <dhaumann@kde.org>
+    Copyright (C) 2013 Gerald Senarclens de Grancy <oss@senarclens.eu>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "variablelineedit.h"
 
-#include "variableitem.h"
-#include "variablelistview.h"
 #include "kateautoindent.h"
-#include "katesyntaxmanager.h"
-#include "kateschema.h"
-#include "kateview.h"
 #include "katedocument.h"
 #include "kateglobal.h"
 #include "katerenderer.h"
+#include "kateschema.h"
+#include "katesyntaxmanager.h"
+#include "kateview.h"
+#include "variableitem.h"
+#include "variablelistview.h"
 
 #include <QApplication>
 #include <QComboBox>
@@ -49,7 +49,7 @@ VariableLineEdit::VariableLineEdit(QWidget *parent)
     m_listview = nullptr;
 
     QHBoxLayout *hl = new QHBoxLayout();
-    hl->setMargin(0);
+    hl->setContentsMargins(0, 0, 0, 0);
     hl->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     setLayout(hl);
 
@@ -65,7 +65,7 @@ VariableLineEdit::VariableLineEdit(QWidget *parent)
     m_popup->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
     QVBoxLayout *l = new QVBoxLayout(m_popup);
     l->setSpacing(0);
-    l->setMargin(0);
+    l->setContentsMargins(0, 0, 0, 0);
     m_popup->setLayout(l);
 
     // forward text changed signal
@@ -186,7 +186,7 @@ void VariableLineEdit::addKateItems(VariableListView *listview)
     listview->addItem(item);
 
     // Add 'end-of-line' (eol) to list
-    item = new VariableStringListItem(QStringLiteral("end-of-line"), { QStringLiteral("unix"), QStringLiteral("mac"), QStringLiteral("dos") }, docConfig->eolString());
+    item = new VariableStringListItem(QStringLiteral("end-of-line"), {QStringLiteral("unix"), QStringLiteral("mac"), QStringLiteral("dos")}, docConfig->eolString());
     item->setHelpText(i18nc("short translation please", "Sets the end of line mode."));
     listview->addItem(item);
 
@@ -201,25 +201,24 @@ void VariableLineEdit::addKateItems(VariableListView *listview)
     listview->addItem(item);
 
     // Add 'font-size' to list
-    item = new VariableIntItem(QStringLiteral("font-size"), rendererConfig->font().pointSize());
+    item = new VariableIntItem(QStringLiteral("font-size"), rendererConfig->baseFont().pointSize());
     static_cast<VariableIntItem *>(item)->setRange(4, 128);
     item->setHelpText(i18nc("short translation please", "Set the point size of the document font."));
     listview->addItem(item);
 
     // Add 'font' to list
-    item = new VariableFontItem(QStringLiteral("font"), rendererConfig->font());
+    item = new VariableFontItem(QStringLiteral("font"), rendererConfig->baseFont());
     item->setHelpText(i18nc("short translation please", "Set the font of the document."));
     listview->addItem(item);
 
     // Add 'syntax' (hl) to list
     /* Prepare list of highlighting modes */
-    const int count = KateHlManager::self()->highlights();
-    QStringList hl;
-    for (int z = 0; z < count; ++z) {
-        hl << KateHlManager::self()->hlName(z);
+    QStringList hls;
+    for (const auto &hl : KateHlManager::self()->modeList()) {
+        hls << hl.name();
     }
 
-    item = new VariableStringListItem(QStringLiteral("syntax"), hl, hl.at(0));
+    item = new VariableStringListItem(QStringLiteral("syntax"), hls, hls.at(0));
     if (activeDoc) {
         static_cast<VariableStringListItem *>(item)->setValue(activeDoc->highlightingMode());
     }
@@ -304,7 +303,9 @@ void VariableLineEdit::addKateItems(VariableListView *listview)
 
     // Add 'scheme' to list
     QStringList schemas;
-    Q_FOREACH (const KateSchema &schema, KTextEditor::EditorPrivate::self()->schemaManager()->list()) {
+    const auto schemaList = KTextEditor::EditorPrivate::self()->schemaManager()->list();
+    schemas.reserve(schemaList.size());
+    for (const KateSchema &schema : schemaList) {
         schemas.append(schema.rawName);
     }
     item = new VariableStringListItem(QStringLiteral("scheme"), schemas, rendererConfig->schema());
@@ -374,4 +375,3 @@ QString VariableLineEdit::text()
 {
     return m_lineedit->text();
 }
-
